@@ -7,13 +7,13 @@ use warnings;
 use Scalar::Util qw/reftype refaddr/;
 use Encode qw/decode encode/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our (%HELP, @MAYBE, $caller, $destruct);
 
 BEGIN {
 	%HELP = (
 		arrayref => sub { return map { $_[0]->($_) } @{ $_[1] } },
-		hashref => sub { map { $caller->can('filter_keys') && $caller->filter_keys($_[1]->{$_}, $_) ? 0 
+		hashref => sub { grep { $caller->can('filter_keys') && $caller->filter_keys($_[1]->{$_}, $_) ? 0 
 			: $destruct ? ($_[0]->($_) => $_[0]->($_[1]->{$_})) : do { $_[1]->{$_} = $_[0]->($_[1]->{$_}) } } keys %{ $_[1] }; },
 		scalarref => sub { $$_[1] =~ m/1|0/ ? $_[1] : $_[0]->($$_[1]) },
 		scalar => sub { eval { $_[1] = $_[0]->($_, $_[1], Encode::FB_CROAK); 1; } and last foreach @MAYBE; $_[1]; }
@@ -72,13 +72,13 @@ Struct::WOP - deeply encode/decode a struct
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
 =head1 SYNOPSIS
 
-    use Struct::WOP qw/maybe_decode/ => [qw/UTF-8/];
+	use Struct::WOP qw/maybe_decode/ => [qw/UTF-8/];
 
 	sub encoded_world_of_pain {
 		maybe_decode(@_);
